@@ -91,11 +91,6 @@ arma::Col<arma::s32> get_value(SEXP exp) {
 	return arma::conv_to< arma::Col<arma::s32> >::from(arma::Col<int>(ptr, Rf_length(exp), false, true));
 }
 
-template<>
-Indices get_value(SEXP exp) {
-	return Indices(get_value<arma::Col<arma::u32> >(exp));
-}
-
 template<>
 arma::sp_mat get_value(SEXP exp) {
 
@@ -115,7 +110,7 @@ arma::sp_mat get_value(SEXP exp) {
 		return m;
 	}
 
-	arma::uword* new_row_indices = arma::memory::acquire_chunked < uword > (n_nonzero + 1);
+    arma::uword* new_row_indices = arma::memory::acquire_chunked < arma::uword > (n_nonzero + 1);
 	double* new_values = arma::memory::acquire_chunked<double>(n_nonzero + 1);
 
 	arma::arrayops::copy(new_values, REAL(values), n_nonzero);
